#!/bin/bash -x

if [[ -z $1 ]]; then
  echo "Please, provide path to the plugin (jpi/hpi) file"
  exit 1;
fi

if [[ ! -f $1 ]]; then
  echo "File $1 doesn't exist, please check the path"
  exit 1;
fi

PLUGIN_FILENAME=$(basename "$1")

ORIG_PLUGIN_NAME=${PLUGIN_FILENAME%.*}
PLUGIN_NAME=$(echo "${ORIG_PLUGIN_NAME}" | sed s/-//g )

PLUGIN_SOURCE_DIR="./${ORIG_PLUGIN_NAME}"

# put plugin to src directory
# before make some cleaning
rm -rf "${PLUGIN_SOURCE_DIR}"
mkdir -p "${PLUGIN_SOURCE_DIR}"
cp -rv "$1" "${PLUGIN_SOURCE_DIR}"

tee "specs/trusty/debian/jenkins-plugin-${PLUGIN_NAME}.install" <<EOF
${ORIG_PLUGIN_NAME}/${PLUGIN_FILENAME} usr/share/jenkins-plugin-${PLUGIN_NAME}
EOF

tee "specs/trusty/debian/jenkins-plugin-${PLUGIN_NAME}.postinst" <<EOF
#!/bin/bash

set -e

if [[ -f /etc/default/jenkins ]]; then
  . /etc/default/jenkins

  cp "/usr/share/jenkins-plugin-${PLUGIN_NAME}/${PLUGIN_FILENAME}" "\${JENKINS_HOME}/plugins/"

  chown -R "\${JENKINS_USER}:\${JENKINS_GROUP}" "\${JENKINS_HOME}/plugins/"

  invoke-rc.d jenkins restart
fi

EOF

tee "specs/trusty/debian/jenkins-plugin-${PLUGIN_NAME}.postrm" <<EOF
#!/bin/bash

set -e

if [[ -f /etc/default/jenkins ]]; then
  . /etc/default/jenkins

  invoke-rc.d jenkins stop

  rm "\${JENKINS_HOME}/plugins/${PLUGIN_FILENAME}"
  rm -r "\${JENKINS_HOME}/plugins/${ORIG_PLUGIN_NAME}/"

  invoke-rc.d jenkins start
fi

EOF

# updating control file
sed -i "/binary:Version/s/$/, jenkins-plugin-${PLUGIN_NAME} (= \${binary:Version})/" specs/trusty/debian/control

echo "Updating control file, please open and edit it manually in oder to provide description and dependancies"
tee -a specs/trusty/debian/control <<EOF

Package: jenkins-plugin-${PLUGIN_NAME}
Section: extra
Priority: optional
Architecture: all
Description: [Description]
 .
EOF
